#!/bin/bash
#

source ${PRODUCTS}/setup
OS=`uname`
if [ ${OS} = "Darwin" ]
then
    flvr=`ups flavor -2`
else
    flvr=`ups flavor`
fi
mydir=${PRODUCTS}/mysql_client/v5_1_56/${flvr}-gcc45
sourcedir=${PRODUCTS}/mysql_client/v5_1_56/source/mysql-5.1.56

if [ -z ${flvr} ]
then
   echo "ERROR: could not determine flavor for this platform"
   echo "       something is very wrong"
   exit 1
fi

mkdir -p ${mydir}/build
if [ ! -d ${mydir}/build ]
then
   echo "ERROR: failed to create ${mydir}/build"
   exit 1
fi

# setup gcc
setup gcc v4_5_1
gccver=`gcc --version | head -1 | cut -f3 -d" " | cut -f1-2 -d"."`
gccfullver=`gcc --version | head -1 | cut -f3 -d" "`
if [ ${gccver} = "4.5" ]
then
  echo " OK - gcc version is ${gccfullver}"
else
  echo "ERROR: wrong gcc version ${gccfullver}"
  exit 1
fi

set -x

cd ${mydir}/build

CFLAGS="-O3" CXX=gcc CXXFLAGS="-O3 -felide-constructors \
       -fno-exceptions -fno-rtti" ${sourcedir}/configure \
       --prefix=${mydir} --without-server --with-mysqld-ldflags=-all-static

make 
make install 

set +x

if [ ! -d ${mydir}/lib ]
then
   echo "ERROR: failed to create ${mydir}/lib"
   echo "       Something is very wrong"
   exit 1
fi

if [ ! -d ${mydir}/bin ]
then
   echo "ERROR: failed to create ${mydir}/bin"
   echo "       Something is very wrong"
   exit 1
fi

# this should not complain
echo "Finished building mysql_client for flavor ${flvr}"
echo "Declaring mysql_client v5_1_56 for this flavor"
if [ ${OS} = "Darwin" ]
then
   ups declare mysql_client v5_1_56 -r mysql_client/v5_1_56 -2 -m mysql_client.table -q gcc45
else 
   ups declare mysql_client v5_1_56 -r mysql_client/v5_1_56 -4 -m mysql_client.table -q gcc45
fi
setup mysql_client v5_1_56 -q gcc45
echo "mysql_client is installed at ${MYSQL_CLIENT_DIR}"

exit 0

# notes below are from mysql-5.1.56/INSTALL-SOURCE

   --enable-assembler Use assembler versions of some string functions
   --without-server Only build the client

   If you are using a version of gcc recent enough to understand the
   -fno-exceptions option, it is very important that you use this
   option. Otherwise, you may compile a binary that crashes randomly.
   Also use -felide-constructors and -fno-rtti along with
   -fno-exceptions. When in doubt, do the following:
CFLAGS="-O3" CXX=gcc CXXFLAGS="-O3 -felide-constructors \
       -fno-exceptions -fno-rtti" ./configure \
       --prefix=/usr/local/mysql --enable-assembler \
       --with-mysqld-ldflags=-all-static

   On most systems, this gives you a fast and stable binary.
